@@ -154,7 +154,6 @@ class TestDistribution:
         result.stdout.fnmatch_lines(["*2*Python*", "*2 failed, 1 passed, 1 skipped*"])
         assert result.ret == 1
 
-    @pytest.mark.xfail("sys.platform.startswith('java')", run=False)
     def test_dist_tests_with_crash(self, pytester: pytest.Pytester) -> None:
         if not hasattr(os, "kill"):
             pytest.skip("no os.kill")
@@ -603,11 +602,10 @@ def test_config_initialization(
 def test_crashing_item(pytester, when) -> None:
     """Ensure crashing item is correctly reported during all testing stages"""
     code = dict(setup="", call="", teardown="")
-    code[when] = "py.process.kill(os.getpid())"
+    code[when] = "os._exit(1)"
     p = pytester.makepyfile(
         """
         import os
-        import py
         import pytest
 
         @pytest.fixture
@@ -742,7 +740,7 @@ def test_sub_plugins_disabled(pytester, plugin) -> None:
             pass
     """
     )
-    result = pytester.runpytest(p1, "-n1", "-p", "no:%s" % plugin)
+    result = pytester.runpytest(p1, "-n1", "-p", f"no:{plugin}")
     assert result.ret == 0
     result.stdout.fnmatch_lines("*1 passed*")
 
@@ -1245,22 +1243,14 @@ class TestFileScope:
             "test_b.py::TestB", result.outlines
         )
 
-        assert (
-            test_a_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
-        assert (
-            test_b_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
+        assert test_a_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
+        assert test_b_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
 
     def test_by_class(self, pytester: pytest.Pytester) -> None:
         pytester.makepyfile(
@@ -1285,22 +1275,14 @@ class TestFileScope:
             "test_a.py::TestB", result.outlines
         )
 
-        assert (
-            test_a_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
-        assert (
-            test_b_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
+        assert test_a_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
+        assert test_b_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
 
     def test_module_single_start(self, pytester: pytest.Pytester) -> None:
         """Fix test suite never finishing in case all workers start with a single test (#277)."""
@@ -1347,22 +1329,14 @@ class TestGroupScope:
             "test_b.py::TestA", result.outlines
         )
 
-        assert (
-            test_a_workers_and_test_count
-            in (
-                {"gw0": 5},
-                {"gw1": 0},
-            )
-            or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 5})
-        )
-        assert (
-            test_b_workers_and_test_count
-            in (
-                {"gw0": 5},
-                {"gw1": 0},
-            )
-            or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 5})
-        )
+        assert test_a_workers_and_test_count in (
+            {"gw0": 5},
+            {"gw1": 0},
+        ) or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 5})
+        assert test_b_workers_and_test_count in (
+            {"gw0": 5},
+            {"gw1": 0},
+        ) or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 5})
         assert (
             test_a_workers_and_test_count.items()
             == test_b_workers_and_test_count.items()
@@ -1392,22 +1366,14 @@ class TestGroupScope:
             "test_a.py::TestB", result.outlines
         )
 
-        assert (
-            test_a_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
-        assert (
-            test_b_workers_and_test_count
-            in (
-                {"gw0": 10},
-                {"gw1": 0},
-            )
-            or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
-        )
+        assert test_a_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_a_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
+        assert test_b_workers_and_test_count in (
+            {"gw0": 10},
+            {"gw1": 0},
+        ) or test_b_workers_and_test_count in ({"gw0": 0}, {"gw1": 10})
         assert (
             test_a_workers_and_test_count.items()
             == test_b_workers_and_test_count.items()
@@ -1576,3 +1542,22 @@ class TestAPI:
         assert xdist.get_xdist_worker_id(fake_request) == "gw5"
         del fake_request.config.workerinput
         assert xdist.get_xdist_worker_id(fake_request) == "master"
+
+
+def test_collection_crash(testdir):
+    p1 = testdir.makepyfile(
+        """
+        assert 0
+    """
+    )
+    result = testdir.runpytest(p1, "-n1")
+    assert result.ret == 1
+    result.stdout.fnmatch_lines(
+        [
+            "gw0 I",
+            "gw0 [[]0[]]",
+            "*_ ERROR collecting test_collection_crash.py _*",
+            "E   assert 0",
+            "*= 1 error in *",
+        ]
+    )
